==> com.liferay.app.builder.web-1.0.2.jar: META-INF/resources/js/hooks/useRequest.es.js <==
Liferay.Loader.define("app-builder-web@1.0.2/js/hooks/useRequest.es", ['module', 'exports', 'require', 'frontend-js-react-web$react', '../utils/client.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _react = require("frontend-js-react-web$react");

  var _client = require("../utils/client.es");

  function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
  }

  function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance");
  }

  function _iterableToArrayLimit(arr, i) {
    var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;_e = err;
    } finally {
      try {
        if (!_n && _i["return"] != null) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }return _arr;
  }

  function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
  }

  var _default = function _default(endpoint) {
    var _useState = (0, _react.useState)({
      error: null,
      isLoading: true,
      response: {}
    }),
        _useState2 = _slicedToArray(_useState, 2),
        state = _useState2[0],
        setState = _useState2[1];

    (0, _react.useEffect)(function () {
      (0, _client.request)(endpoint).then(function (response) {
        return response.json();
      }).then(function (response) {
        setState({
          error: null,
          isLoading: false,
          response: response
        });
      })["catch"](function (error) {
        setState({
          error: error,
          isLoading: false,
          response: {}
        });
      });
    }, [endpoint]);
    return state;
  };

  exports["default"] = _default;
  //# sourceMappingURL=useRequest.es.js.map
});
//# sourceMappingURL=useRequest.es.js.map

==> com.liferay.app.builder.web-1.0.18.jar: META-INF/resources/js/hooks/useRequest.es.js <==
Liferay.Loader.define("app-builder-web@1.0.18/js/hooks/useRequest.es", ['module', 'exports', 'require', 'frontend-js-react-web$react', '../utils/client.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _react = require("frontend-js-react-web$react");

  var _client = require("../utils/client.es");

  function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
  }

  function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance");
  }

  function _iterableToArrayLimit(arr, i) {
    if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
      return;
    }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;_e = err;
    } finally {
      try {
        if (!_n && _i["return"] != null) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }return _arr;
  }

  function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
  }

  var _default = function _default(endpoint) {
    var _useState = (0, _react.useState)({
      error: null,
      isLoading: true,
      response: {}
    }),
        _useState2 = _slicedToArray(_useState, 2),
        state = _useState2[0],
        setState = _useState2[1];

    (0, _react.useEffect)(function () {
      (0, _client.request)(endpoint).then(function (response) {
        setState({
          error: null,
          isLoading: false,
          response: response
        });
      })["catch"](function (error) {
        setState({
          error: error,
          isLoading: false,
          response: {}
        });
      });
    }, [endpoint]);
    return state;
  };

  exports["default"] = _default;
  //# sourceMappingURL=useRequest.es.js.map
});
//# sourceMappingURL=useRequest.es.js.map
